==> amity-sdk-7.6.0-sources.jar: main/com/amity/socialcloud/sdk/core/data/reaction/ReactionApi.kt <==
package com.amity.socialcloud.sdk.core.data.reaction

import com.amity.socialcloud.sdk.core.data.reaction.dto.ReactionAddedDto
import com.amity.socialcloud.sdk.core.data.reaction.dto.ReactionRemovedDto
import com.ekoapp.ekosdk.internal.api.dto.EkoReactionAndUserListDto
import com.ekoapp.ekosdk.internal.api.socket.request.AddLiveReactionsRequest
import com.ekoapp.ekosdk.internal.api.socket.request.AddReactionRequest
import com.ekoapp.ekosdk.internal.api.socket.request.RemoveReactionRequest
import com.google.gson.JsonObject
import io.reactivex.rxjava3.core.Single
import retrofit2.http.*

interface ReactionApi {

    @GET("api/v3/reactions")
    fun queryReactions(
        @Query("referenceType") referenceType: String,
        @Query("referenceId") referenceId: String,
        @Query("reactionName") reactionName: String? = null,
        @Query("referenceVersion") referenceVersion: Int? = null,
        @Query("options[limit]", encoded = true) limit: Int? = null,
        @Query("options[token]", encoded = true) token: String? = null
    ): Single<EkoReactionAndUserListDto>

    @POST("api/v2/reactions")
    fun addReaction(
        @Body request: AddReactionRequest
    ): Single<ReactionAddedDto>

    @HTTP(method = "DELETE", path = "api/v2/reactions", hasBody = true)
    fun removeReaction(
        @Body request: RemoveReactionRequest,
    ): Single<ReactionRemovedDto>

    @POST("api/v1/reactions/live")
    fun addLiveReactions(
        @Body request: AddLiveReactionsRequest
    ): Single<JsonObject>

}

==> amity-sdk-7.15.0-sources.jar: main/com/amity/socialcloud/sdk/core/data/reaction/ReactionApi.kt <==
package com.amity.socialcloud.sdk.core.data.reaction

import com.amity.socialcloud.sdk.core.data.reaction.dto.ReactionAddedDto
import com.amity.socialcloud.sdk.core.data.reaction.dto.ReactionRemovedDto
import com.ekoapp.ekosdk.internal.api.dto.EkoReactionAndUserListDto
import com.ekoapp.ekosdk.internal.api.socket.request.AddLiveReactionsRequest
import com.ekoapp.ekosdk.internal.api.socket.request.AddReactionRequest
import com.ekoapp.ekosdk.internal.api.socket.request.AddRoomReactionsRequest
import com.ekoapp.ekosdk.internal.api.socket.request.RemoveReactionRequest
import com.google.gson.JsonObject
import io.reactivex.rxjava3.core.Single
import retrofit2.http.*

interface ReactionApi {

    @GET("api/v3/reactions")
    fun queryReactions(
        @Query("referenceType") referenceType: String,
        @Query("referenceId") referenceId: String,
        @Query("reactionName") reactionName: String? = null,
        @Query("referenceVersion") referenceVersion: Int? = null,
        @Query("options[limit]", encoded = true) limit: Int? = null,
        @Query("options[token]", encoded = true) token: String? = null
    ): Single<EkoReactionAndUserListDto>

    @POST("api/v2/reactions")
    fun addReaction(
        @Body request: AddReactionRequest
    ): Single<ReactionAddedDto>

    @HTTP(method = "DELETE", path = "api/v2/reactions", hasBody = true)
    fun removeReaction(
        @Body request: RemoveReactionRequest,
    ): Single<ReactionRemovedDto>

    @POST("api/v1/reactions/live")
    fun addLiveReactions(
        @Body request: AddLiveReactionsRequest
    ): Single<JsonObject>

    @POST("api/v1/reactions/live")
    fun addRoomReactions(
        @Body request: AddRoomReactionsRequest
    ): Single<JsonObject>

}
